@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2018 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -31,15 +31,16 @@ from glances.plugins.glances_core import Plugin as CorePlugin
 from glances.plugins.glances_plugin import GlancesPlugin
 
 
-def convert_timedelta(delta):
-    """Convert timedelta to human-readable time."""
-    days, total_seconds = delta.days, delta.seconds
-    hours = days * 24 + total_seconds // 3600
-    minutes = (total_seconds % 3600) // 60
-    seconds = str(total_seconds % 60).zfill(2)
-    microseconds = str(delta.microseconds)[:2].zfill(2)
+def seconds_to_hms(input_seconds):
+    """Convert seconds to human-readable time."""
+    minutes, seconds = divmod(input_seconds, 60)
+    hours, minutes = divmod(minutes, 60)
 
-    return hours, minutes, seconds, microseconds
+    hours = int(hours)
+    minutes = int(minutes)
+    seconds = str(int(seconds)).zfill(2)
+
+    return hours, minutes, seconds
 
 
 def split_cmdline(cmdline):
@@ -90,9 +91,10 @@ class Plugin(GlancesPlugin):
         'name': '[{}]'
     }
 
-    def __init__(self, args=None):
+    def __init__(self, args=None, config=None):
         """Init the plugin."""
         super(Plugin, self).__init__(args=args,
+                                     config=config,
                                      stats_init_value=[])
 
         # We want to display the stat in the curse interface
@@ -114,6 +116,12 @@ class Plugin(GlancesPlugin):
         # Use to optimize space (see https://github.com/nicolargo/glances/issues/959)
         self.pid_max = glances_processes.pid_max
 
+        # Set the default sort key if it is defined in the configuration file
+        if config is not None:
+            if 'processlist' in config.as_dict() and 'sort_key' in config.as_dict()['processlist']:
+                logger.debug('Configuration overwrites processes sort key by {}'.format(config.as_dict()['processlist']['sort_key']))
+                glances_processes.set_sort_key(config.as_dict()['processlist']['sort_key'], False)
+
         # Note: 'glances_processes' is already init in the processes.py script
 
     def get_key(self):
@@ -223,7 +231,8 @@ class Plugin(GlancesPlugin):
             ret.append(self.curse_add_line(msg))
         # TIME+
         try:
-            delta = timedelta(seconds=sum(p['cpu_times']))
+            # Sum user and system time
+            user_system_time = p['cpu_times'][0] + p['cpu_times'][1]
         except (OverflowError, TypeError) as e:
             # Catch OverflowError on some Amazon EC2 server
             # See https://github.com/nicolargo/glances/issues/87
@@ -233,7 +242,7 @@ class Plugin(GlancesPlugin):
             msg = self.layout_header['time'].format('?')
             ret.append(self.curse_add_line(msg, optional=True))
         else:
-            hours, minutes, seconds, microseconds = convert_timedelta(delta)
+            hours, minutes, seconds = seconds_to_hms(user_system_time)
             if hours > 99:
                 msg = '{:<7}h'.format(hours)
             elif 0 < hours < 100:
@@ -327,7 +336,9 @@ class Plugin(GlancesPlugin):
             else:
                 msg = self.layout_stat['name'].format(p['name'])
                 ret.append(self.curse_add_line(msg, splittable=True))
-        except UnicodeEncodeError:
+        except (TypeError, UnicodeEncodeError) as e:
+            # Avoid crach after running fine for several hours #1335
+            logger.debug("Can not decode command line '{}' ({})".format(cmdline, e))
             ret.append(self.curse_add_line('', splittable=True))
 
         # Add extended stats but only for the top processes
